@@ -38,7 +38,7 @@ nil = Nil()
 def cons(l, r):
     return Cons(l, r)
 def sym(name):
-    return SymExp(name)
+    return Symbol(name)
 def hd(e):
     assert isinstance(e, Cons), "Head of nil"
     return e.left
